@@ -2,56 +2,48 @@ package Aspect::Library::Singleton;
 
 use strict;
 use warnings;
-use Aspect::Modular        ();
-use Aspect::Advice::Before ();
-use Aspect::Pointcut::Call ();
+use Carp;
+use Aspect;
 
-our $VERSION = '0.97_06';
-our @ISA     = 'Aspect::Modular';
+use base 'Aspect::Modular';
 
-my %CACHE = ();
+my %Cache;
 
 sub get_advice {
-	my $self = shift;
-	Aspect::Advice::Around->new(
-		lexical  => $self->lexical,
-		pointcut => Aspect::Pointcut::Call->new(shift),
-		code     => sub {
-			my $class = $_->self;
-			$class    = ref $class || $class;
-			if ( exists $CACHE{$class} ) {
-				$_->return_value($CACHE{$class});
-			} else {
-				$_->proceed;
-				unless ( $_->exception ) {
-					$CACHE{$class} = $_->return_value;
-				}
-			}
-		},
-	);
+	my ($self, $constructor_matcher) = @_;
+	return before {
+		my $context = shift;
+		my $class   = $context->self;
+		$class      = ref $class || $class;
+
+		if (exists $Cache{$class})
+			{ $context->return_value($Cache{$class}) }
+		else
+			{ $Cache{$class} = $context->run_original }
+
+	} call $constructor_matcher;
 }
 
 1;
 
-__END__
-
-=pod
-
 =head1 NAME
 
 Aspect::Library::Singleton - A singleton aspect
 
 =head1 SYNOPSIS
 
-  use Aspect;
   use Aspect::Singleton;
-  
+
   aspect Singleton => 'Foo::new';
-  
+
   my $f1 = Foo->new;
   my $f2 = Foo->new;
-  
-  # Both $f1 and $f2 refer to the same object
+
+  # now $f1 and $f2 refer to the same object
+
+=head1 SUPER
+
+L<Aspect::Modular>
 
 =head1 DESCRIPTION
 
@@ -85,21 +77,12 @@ No package variable or method is added to the callers namespace
 
 Note that this is just a special case of memoizing.
 
-=head1 AUTHORS
+=head1 SEE ALSO
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+See the L<Aspect|::Aspect> pods for a guide to the Aspect module.
 
-Marcel GrE<uuml>nauer E<lt>marcel@cpan.orgE<gt>
-
-Ran Eilam E<lt>eilara@cpan.orgE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2001 by Marcel GrE<uuml>nauer
-
-Some parts copyright 2009 - 2011 Adam Kennedy.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+You can find an example comparing the OO and AOP solutions in the
+C<examples/> directory of the distribution.
 
 =cut
+
